==> jndi-server-5.13.0-sources.jar: fr/dyade/aaa/jndi2/server/RequestContext.java <==
/*
 * JORAM: Java(TM) Open Reliable Asynchronous Messaging
 * Copyright (C) 2001 - 2003 ScalAgent Distributed Technologies
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA.
 *
 * Initial developer(s): Sofiane Chibani
 * Contributor(s): David Feliot, Nicolas Tachker
 */
package fr.dyade.aaa.jndi2.server;

import fr.dyade.aaa.jndi2.msg.*;

import javax.naming.*;

public abstract class RequestContext 
    implements java.io.Serializable {

  private CompositeName resolvedName;

  public RequestContext() {
    this.resolvedName = null;
  }

  public abstract JndiRequest getRequest();

  public abstract void reply(JndiReply reply);

  public void setResolvedName(CompositeName resolvedName) {
    this.resolvedName = resolvedName;
  }

  public final CompositeName getResolvedName() {
    return resolvedName;
  }

  public String toString() {
    return '(' + super.toString() +
      ",resolvedName=" + resolvedName + ')';
  }
}

==> jndi-server-5.19.0-sources.jar: fr/dyade/aaa/jndi2/server/RequestContext.java <==
/*
 * JORAM: Java(TM) Open Reliable Asynchronous Messaging
 * Copyright (C) 2001 - 2019 ScalAgent Distributed Technologies
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA.
 *
 * Initial developer(s): Sofiane Chibani
 * Contributor(s): David Feliot, Nicolas Tachker
 */
package fr.dyade.aaa.jndi2.server;

import fr.dyade.aaa.jndi2.msg.*;

import javax.naming.*;

public abstract class RequestContext implements java.io.Serializable {
  /** define serialVersionUID for interoperability, fix with 5.15.0 value */
  private static final long serialVersionUID = 9185021686499463557L;

  private CompositeName resolvedName;

  public RequestContext() {
    this.resolvedName = null;
  }

  public abstract JndiRequest getRequest();

  public abstract void reply(JndiReply reply);

  public void setResolvedName(CompositeName resolvedName) {
    this.resolvedName = resolvedName;
  }

  public final CompositeName getResolvedName() {
    return resolvedName;
  }

  public String toString() {
    return '(' + super.toString() +
      ",resolvedName=" + resolvedName + ')';
  }
}
